<?php

module_load_include ( 'inc', 'icl_core', 'icl_core.constants' );
module_load_include ( 'inc', 'icl_core', 'icl_core.settings' );
module_load_include ( 'inc', 'icl_content', 'icl_content.contact_form' );


/**
 * Enter description here...
 *
 * @return unknown
 */
function icl_content_dashboard_filter_form() {
  $form = array(
    '#type' => 'fieldset',    
  );
  
  $languages = locale_language_list();
  $languages[] = t ('Language neutral');
  $default = _icl_content_default_value('language', language_default()->language);
  if ($default == '') {
    // handle language neutral setting
    $default = '0';
  }
  $form['language'] = array(
    '#title' => t('Show documents in'),
    '#type' => 'radios',    
    '#options' => $languages,
    '#default_value' => $default,
  );
  
  $form['translation'] = array(
    '#title' => t('Translation status'),
    '#type' => 'radios',    
    '#options' => array(
      'all' => t('All documents'),
      'update' => t('Not translated or needs updating'),
    ),
    '#default_value' => _icl_content_default_value('translation', 'all'),
  );
  
  $form['further'] = array(    
    '#type' => 'markup',
    '#prefix' => '<div id="icl-dashboard-further" class="form-item"><label id="icl-dashboard-further-label">'.t('Filter further by').':',    
    '#suffix' => '</label></div>',
  );
  
  $form['further']['status'] = array(
    '#type' => 'fieldset',
  );
  $form['further']['status']['status_enabled'] = array(   
    '#type' => 'checkbox',
    '#default_value' => _icl_content_default_value('status_enabled', FALSE),
  );
  $form['further']['status']['status_status'] = array(
    '#title' => t('Status'),
    '#type' => 'select',
    '#options' => array(
      'status-1' => t('published'),
      'status-0' => t('not published'),
      'promote-1' => t('promoted'),
      'promote-0' => t('not promoted'),
      'sticky-1' => t('sticky'),
      'sticky-0' => t('not sticky'),
    ),
    '#default_value' => _icl_content_default_value('status', 'status-1'),
  );
  
  $form['further']['type'] = array(
    '#type' => 'fieldset',
  );
  $form['further']['type']['type_enabled'] = array(    
    '#type' => 'checkbox',
    '#default_value' => _icl_content_default_value('type_enabled', FALSE),
  );
  $types = array();
  foreach (node_get_types() as $type => $details) {
    $types[$type] = $details->name;    
  }
  // Add a block type
  $types['block'] = 'Block (i18n)';

  if (is_standard_contact_form_enabled()) {  
    // Add standard contact form
    $types['standard_contact_form'] = 'Contact Form';
  }
  
  $form['further']['type']['type_type'] = array(
    '#title' => t('Type'),
    '#type' => 'select',
    '#options' => $types,
    '#default_value' => _icl_content_default_value('type', ''),
  );
  
  $form['op'] = array(
    '#value' => t('Update display'),
    '#type' => 'submit',
    '#submit' => array('icl_content_dashboard_filter_form_submit'),
  );
  
  return $form;
}

/**
 * Enter description here...
 *
 */
function icl_content_dashboard_filter_form_submit($form, &$form_state) {
  global $icl_content_dashboard_filter;
  
  $icl_content_dashboard_filter = array(
    'language' => $form_state['values']['language'],
    'translation' => $form_state['values']['translation'],
    'status_enabled' => $form_state['values']['status_enabled'] == 1,
    'status' => $form_state['values']['status_status'],
    'type_enabled' => $form_state['values']['type_enabled'] == 1,
    'type' => $form_state['values']['type_type'],
  );
  if ($icl_content_dashboard_filter['language'] == '0') {
    // handle language neutral setting
    $icl_content_dashboard_filter['language'] = '';
  }
  $form_state['rebuild'] = TRUE;
}

/**
 * Enter description here...
 *
 * @return unknown
 */
function icl_content_dashboard_nodes_form($dashboard_mode = TRUE) {
  $form = array(
    'title' => array(),
    'type' => array(),
    'status' => array(),
    'translation' => array(),
  );
  $form['#theme'] = 'icl_content_dashboard_nodes';
  $node_types = node_get_types();
  $nodes = array();
  if ($dashboard_mode) {
    $query = icl_content_dashboard_build_filter_query();
  } else {
    $query = icl_content_review_build_filter_query();
  }
  while ($node = db_fetch_object($query)) {
    if ($node->type == 'icl_block_marker') {
      $nid = 'block-'. $node->nid;
    } else if ($node->type == 'icl_contact_form_marker') {
      $nid = 'contact-'.$node->nid;
    } else {
      $nid = $node->nid;
    }
    $nodes[$nid] = '';

    if ($dashboard_mode) {
      $form['title'][$nid] = array('#value' => l($node->title, 'node/'.$node->nid));
    } else {
      // translation review mode
      // add a parameter to the link.
      $form['title'][$nid] = array('#value' => l($node->title, 'node/'.$node->nid, array('query' => array('review' => '1'))));
    }
     
    if ($node->type == 'icl_block_marker') {
      $title = $node->title;
      if ($title == "") {
        $title = "(no title)";
      }
      $form['title'][$nid] = array('#value' => l($title, 'admin/build/block/configure/block/'.$node->nid));
      
      $form['type'][$nid] = array('#value' => t('Block (i18n)'));
      $form['status'][$nid] = array('#value' => t('Not applicable'));
      $form['translation'][$nid] = array('#value' => empty($node->language) ? t('Language neutral') : theme('icl_content_fancy_status', $node, TRUE));

    } else if ($node->type == 'icl_contact_form_marker') {
      $title = $node->title;
      $form['title'][$nid] = array('#value' => l($title, 'admin/build/contact'));

      $form['type'][$nid] = array('#value' => t('Contact Form'));
      $form['status'][$nid] = array('#value' => t('Enabled'));
      $form['translation'][$nid] = array('#value' => empty($node->language) ? t('Language neutral') : theme('icl_content_fancy_status', $node, TRUE));
    } else {
      
      $form['type'][$nid] = array('#value' => $node_types[$node->type]->name);
      $form['status'][$nid] = array('#value' => $node->status == 1 ? t('Published') : t('Unpublished'));
      $form['translation'][$nid] = array('#value' => empty($node->language) ? t('Language neutral') : theme('icl_content_fancy_status', $node, TRUE));
    }
    
    $form['translation'][$nid]['result-'.$nid] = array(
      '#type' => 'markup',
      '#prefix' => '<div id="result-'.$nid.'">',
      '#suffix' => '</div>',
      '#value' => '<!- This will be replaced ->',
    );
    /*$form['translation'][$nid]['word_count'.$nid] = array(
      '#type' => 'button',
      '#value' => 'Details',
      '#submit' => array('icl_content_icl_status'),
      '#ahah' => array(
        'path' => 'icl_content/icl_status/'.$nid,
        'wrapper' => 'result-'.$nid,
        'method' => 'replace',
        'effect' => 'fade',
        'progress' => array(
          'type' => 'throbber',
        )
        ),
    );
    */
    $ahah_binding = array(
      'url' => url('icl_content/icl_status/'.$nid),
      'event' => 'click',
      'wrapper' => 'result-'.$nid,
      'selector' => '#details-'.$nid,
      'method' => 'replace',
      'effect' => 'fade',
      'progress' => array(
        'type' => 'throbber',
      ),
      );
    $form['translation'][$nid]['#value'] = '<a href="#" id="details-'.$nid.'">'.$form['translation'][$nid]['#value'].'</a>';
    
    drupal_add_js(array('ahah' => array('details-'.$nid => $ahah_binding)), 'setting');
    
  } 
  if ($dashboard_mode) {
    $form['nodes'] = array('#type' => 'checkboxes', '#options' => $nodes);
  }
  
  return $form;
}

/**
 * Enter description here...
 *
 */
function icl_content_dashboard_build_filter_query() {
  global $icl_content_dashboard_filter;
  
  $node_types = _icl_content_translatable_node_types();
  
  $filter = array();  
  $args = array();  
  $args[] = _icl_content_default_value('language', language_default()->language );
  
  if (isset($icl_content_dashboard_filter['translation']) && $icl_content_dashboard_filter['translation'] == 'update') {
    $filter['join'] .= ' INNER JOIN {icl_content_status} cs ON n.nid = cs.nid 
                         INNER JOIN {icl_core_status} c ON c.rid = cs.rid 
                         INNER JOIN {icl_node} md ON md.nid = n.nid';
    $filter['icl_where'] .= " AND md.md5 <> cs.md5 AND c.status = " . ICL_STATUS_SUCCESSFUL;
  }
  
  if (isset($icl_content_dashboard_filter['status_enabled']) && $icl_content_dashboard_filter['status_enabled']) {
    list($column, $value) = explode('-', $icl_content_dashboard_filter['status']);
    if (in_array($column, array('status', 'promote', 'sticky'))) {
      $filter['where'] .= " AND n.".$column." = ".$value;
    }
  }

  $type_filter = "";  
  if (isset($icl_content_dashboard_filter['type']) && isset($icl_content_dashboard_filter['type_enabled'])) {
    if ($icl_content_dashboard_filter['type_enabled']) {
      $filter['where'] .= " AND n.type = '". $icl_content_dashboard_filter['type'] . "'";
      $type_filter = $icl_content_dashboard_filter['type'];
    }
  }
  
  $sql  = "SELECT 
             n.nid, 
             n.title, 
             n.type, 
             n.language, 
             n.status,
             n.tnid
           FROM 
             {node} n"
           .$filter['join'].
          " WHERE
             n.type IN ('".implode("', '", $node_types)."') AND 
             n.language = '%s'"
           .$filter['icl_where']
           .$filter['where'];
  
  if (isset($icl_content_dashboard_filter['translation']) && $icl_content_dashboard_filter['translation'] == 'update') {
    // Add a query to include all nodes that haven't been translated yet.
    $sql = "SELECT n.nid, 
                n.title, 
                n.type, 
                n.language, 
                n.status,
                n.tnid
              FROM
                {node} n
              WHERE
                (n.nid not in (select nid from {icl_content_status})) and n.tnid = 0 and language = '" . $args[0] . "'" . $filter['where']. " UNION " . $sql;
  }
  
  // add blocks if required
  
  if (module_exists ( 'i18nblocks' )) {
    if (($type_filter == '' || $type_filter == "block") && $args[0] == "en") {
      $sql = $sql . " UNION SELECT DISTINCT(b.delta), b.title, 'icl_block_marker', 'en', 'visible', '0' FROM {i18n_blocks} i18b";
      $join = " join {blocks} b ";
      $where = " where i18b.language = '' and b.delta = i18b.delta and b.module = 'block'  ";
      if (isset($icl_content_dashboard_filter['translation']) && $icl_content_dashboard_filter['translation'] == 'update') {
        // We need to get the blocks that require update
        
        // We don't know if a block has changed from the core status as we don't hook any saving of blocks.
        // We need to calculate each time.
        
        $query = db_query("SELECT delta FROM {i18n_blocks} WHERE language = ''");
        while ( $bid = db_fetch_object ( $query ) ) {
          $block = block_box_get($bid->delta);
          $block_md5 = icl_content_calculate_block_md5($block);
          
          db_query("UPDATE {icl_block} SET md5 = '%s' WHERE bid = %d", $block_md5, $bid->delta);
        }
        $join .= ' INNER JOIN {icl_block_status} bs ON b.delta = bs.bid 
                           INNER JOIN {icl_core_status} c ON c.rid = bs.rid 
                           INNER JOIN {icl_block} md ON md.bid = b.delta';
        $where .= " AND md.md5 <> bs.md5 AND c.status = " . ICL_STATUS_SUCCESSFUL;
      }
      
      $sql = $sql . $join . $where;
    
      if (isset($icl_content_dashboard_filter['translation']) && $icl_content_dashboard_filter['translation'] == 'update') {
        // also add the blocks that are new and not in icl_block yet
        $sql .= " UNION SELECT
                      DISTINCT(b.delta), b.title, 'icl_block_marker', 'en', 'visible', '0'
                    FROM
                      {i18n_blocks} i18b
                    
                    JOIN
                      {blocks} b
                     
                    WHERE
                      i18b.language = '' and b.delta = i18b.delta and b.module = 'block' AND
                      (b.delta not in (select bid from {icl_block_status}))";
      }  
    }
  }
  
  if (($type_filter == '' || $type_filter == "standard_contact_form") && $args[0] == "en") {
    icl_content_add_contact_form_query($sql, $icl_content_dashboard_filter);
  }
  
  $count_query = "SELECT COUNT(*) FROM (" . $sql . ") tblDerived";

  return pager_query($sql, 30, 0, $count_query, $args);
}


/**
 * Enter description here...
 *
 * @return unknown
 */
function icl_content_dashboard_action_form() {
  $form = array();
  $form['operations'] = array(
    '#type' => 'fieldset',
    '#title' => t('Translation options'),
    '#attributes' => array('id' => 'dashboard-actions'),
  );
  $languages = array();
  $no_languages = array();
  $no_translator_languages = array();
  $defaults = array();
  $icl_core_languages = variable_get('icl_core_languages', array());
  $selected_langauge = _icl_content_default_value('language', language_default()->language);
  $selected_langauge = icl_core_get_language_name($selected_langauge);

  if ($selected_langauge == null) {
    $form['operations']['message'] = array(
      '#type' => 'markup',
      '#prefix' => '<div class="status">',
      '#suffix' => '</div>',
      '#value' => t('Content that is language neutral cannot be sent for translation. Edit the content and set the language if you want to send it for translation'),
    );
  } else {
    
    if (isset($icl_core_languages['langs'][$selected_langauge])) {
      foreach ($icl_core_languages['langs'][$selected_langauge] as $lang) {
        if($icl_core_languages['have_translators'][$selected_langauge][$lang]) {
          $code = icl_core_get_language_code($lang);
          $languages[$code] = t('Translate to @lang', array('@lang' => icl_core_get_drupal_language_name_from_ican_language($lang)));
        } else {
          $no_languages[$code] = t('Translate to @lang (No translators have been assigned yet)', array('@lang' => icl_core_get_drupal_language_name_from_ican_language($lang)));
          $no_translator_languages[] = icl_core_get_drupal_language_name_from_ican_language($lang);
        }
      }
    }
    
    foreach($languages as $code => $value) {
      $defaults[] = $code;
    }
  
    $form['operations']['targets'] = array(
      '#type' => 'checkboxes',
      '#options' => $languages,
      '#default_value' => $defaults,
    );
    if (sizeof($no_languages) > 0) {
      $form['operations']['no_targets'] = array(
        '#type' => 'checkboxes',
        '#options' => $no_languages,
        '#disabled' => TRUE,
      );
      
    }
    
    if (sizeof($languages) == 0 && sizeof($no_translator_languages) == 0) {
      $form['operations']['message'] = array(
        '#type' => 'markup',
        '#prefix' => '<div class="status">',
        '#suffix' => '</div>',
        '#value' => t('No target languages have been set for translating from !language', array('!language' => icl_core_get_drupal_language_name_from_ican_language($selected_langauge))),
      );
    } else if (sizeof($languages) != 0) {
      $form['operations']['translate_request'] = array(
        '#type' => 'submit',
        '#validate' => array('icl_content_dashboard_action_validate'),
        '#submit' => array('icl_content_dashboard_action_submit'),
        '#value' => t('Translate selected documents'),
      );
    }
    
    if (sizeof($no_translator_languages) > 0) {
      $translator_selection = variable_get ( 'icl_core_translator_selection', ICL_CORE_SELECT_TRANSLATORS_ICANLOCALIZE );
      
      foreach ($no_translator_languages as $lang) {
        
        if($translator_selection == ICL_CORE_SELECT_TRANSLATORS_ICANLOCALIZE) {
          $form['operations']['no_translator_'.$lang] = array(
            '#type' => 'markup',
            '#prefix' => '<div class="status"><b>',
            '#suffix' => '</b></div>',
            '#value' => t('No !language translator has been assigned to this project yet.', array('!language' => $lang)),
          );
        } else {
          $form['operations']['no_translator_'.$lang] = array(
            '#type' => 'markup',
            '#prefix' => '<div class="status"><b>',
            '#suffix' => '</b></div>',
            '#value' => t('You haven\'t yet selected any !language translator for this project.', array('!language' => $lang)),
          );
        }
      }      
    }
    
    $form['operations']['balance'] = array(
      '#type' => 'markup',
      '#prefix' => '<div class="status">',
      '#suffix' => '</div>',
      '#value' => t('Your balance with ICanLocalize is $!balance. Visit your !finance page to deposit additional funds.', array('!balance' => $icl_core_languages['balance'], '!finance' => ICL_FINANCE_LINK)),
    );
    
    if ($icl_core_languages['balance'] < variable_get('icl_balance_warning', 50)) {
      drupal_set_message('<b>'. t('Your balance in ICanLocalize is running low. To allow translations to continue, visit your !finance page and deposit additional funds.', array('!finance' => ICL_FINANCE_LINK)) . '</b>', 'error', FALSE);
    }
    
    
    
  }
  
  $form['cost_estimate'] = array(
    '#type' => 'fieldset',
    '#title' => t('Translation cost estimate'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['cost_estimate']['result_count'] = array(
    '#type' => 'markup',
    '#prefix' => '<div id="result-count">',
    '#suffix' => '</div>',
    '#value' => '<!- This will be replaced ->',
  );
  $form['cost_estimate']['word_count'] = array(
    '#type' => 'button',
    '#value' => 'Produce word count for all untranslated contents',
    //'#attributes' => array('onclick' => "javascript:on_word_count_button();return false;"),
    '#submit' => array('icl_content_word_count'),
    '#ahah' => array(
      'path' => 'icl_content/word_count',
      'wrapper' => 'result-count',
      'method' => 'replace',
      'effect' => 'fade',
      'progress' => array(
        'type' => 'throbber',
      )
      ),
  );
  
  return $form;
}

/**
 * Enter description here...
 *
 * @param unknown_type $form
 * @return unknown
 */
function theme_icl_content_dashboard_translation_selection($form) {
  $output = '';  
  foreach ($form['#options'] as $key => $value) {
    $output .= '  <div id="edit-targets-'.$key.'-wrapper" class="form-item">';
    $output .= '    <label for="targets['.$key.']" class="option">'.$value.'</label>';
    $output .= '    <input id="edit-targets-'.$key.'" class="form-checkbox" type="checkbox" value="'.$key.'" name="targets['.$key.']"/>';
    $output .= '  </div>';    
  }
  
  return $output;  
}

/**
 * Enter description here...
 *
 * @param unknown_type $form
 * @param unknown_type $form_state
 */
function icl_content_dashboard_action_validate($form, &$form_state) {
  $nodes = array_filter($form_state['values']['nodes']);
  if (count($nodes) == 0) {
    form_set_error('', t('No items selected.'));
  }
  
  $targets = array_filter($form_state['values']['targets']);
  if (count($targets) == 0) {
    form_set_error('', t('No translation targets were selected.'));
  }  
}

/**
 * Enter description here...
 *
 * @param unknown_type $form
 * @param unknown_type $form_state
 */
function icl_content_dashboard_action_submit($form, &$form_state) {
  $form_state['rebuild'] = TRUE;
    
  // Filter out unchecked nodes
  $content_to_translate = array_filter($form_state['values']['nodes']);
  $nodes = array();
  $blocks = array();
  $contact_form = False;
  foreach($content_to_translate as $content) {
    if (strpos($content, 'block-') === 0) {
      $blocks[] = substr($content, 6);
    } else if (strpos($content, 'contact-') === 0) {
      $contact_form = True;
    } else {
      $nodes[] = $content;
    }
  }

  $langcodes = array();  
  foreach($form_state['values']['targets'] as $key => $value){
      if ($key === $value) {
        $langcodes[] = $value;
      }
  }
  icl_content_dashboard_filter_form_submit($form, $form_state);
  
  icl_content_translate_posts($nodes, $langcodes);
  icl_content_translate_blocks($blocks, $form_state['values']['language'], $langcodes);
  if ($contact_form) {
    icl_content_translate_standard_contact_form($form_state['values']['language'], $langcodes);
  }
}

/**
 * Enter description here...
 *
 * @return unknown
 */
function icl_content_dashboard() {
  $form = array();

  $i18n_not_installed = check_i18n_installed();
  if (sizeof($i18n_not_installed) > 0) {
    $form['i18n_errors'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Missing i18n modules.' ), 
      '#collapsible' => false );
  
    foreach($i18n_not_installed as $id => $module) {
      $form ['i18n_errors'] [$module['module']] = array (
          '#type' => 'markup', 
          '#prefix' => '<div class="error">', 
          '#suffix' => '</div>', 
          '#value' => $module['message'] );
    }
  }

  $form['filter'] = icl_content_dashboard_filter_form();
  $form['nodes'] = icl_content_dashboard_nodes_form();
  $form['pager'] = array('#value' => theme('pager', NULL, 10, 0));
  $form['action'] = icl_content_dashboard_action_form();
  // A small hack to include the CSS and JS
  $form ['#validate'] [] = 'icl_content_dashboard_add_js';
  icl_content_dashboard_add_js ($form);
    
  return $form;
}

function icl_content_dashboard_add_js($form) {
  //foreach($form['action']['operations'] as $key => $value) {
    //if (strpos($key, 'no_translator_') === 0) {
        
      $js = drupal_get_js();
      if (strpos($js, 'icl_dashboard.js') === FALSE) {
        
        // add a call to refresh the the icanlocalize have_translator states for languages.
        $ican_url = url('icl_core/refresh');
        drupal_add_js(
                      array('ican_fetch' =>
                            array('ican_url' => $ican_url)),
                            'setting');
        drupal_add_js(
                      array('ican_word_count' =>
                            array('ican_word_count_url' => url('icl_content/word_count'))),
                            'setting');
        drupal_add_js ( drupal_get_path ( 'module', 'icl_content' ) . '/js/icl_dashboard.js' );
      }
      return;
    //}
  //}
}

/**
 * Enter description here...
 *
 * @return unknown
 */
function _icl_content_translatable_node_types() {
  if (module_exists('content')) {
    $node_types = array_keys(content_types());
  } else {
    $node_types = array_keys(node_get_types());
  }

  foreach ($node_types as $key => $type) {
    $translatable = variable_get('language_content_type_'.$type, false);
    if (!$translatable) {
      unset($node_types[$key]);
    }
  }
  
  return $node_types;
}

/**
 * Helper to set the default_value for the form.
 *
 * @param unknown_type $key
 * @param unknown_type $default
 * @return unknown
 */
function _icl_content_default_value($key, $default) {
  global $icl_content_dashboard_filter;
  
  if (isset($icl_content_dashboard_filter[$key])) {
    return $icl_content_dashboard_filter[$key];
  }
  else if (isset($_GET[$key])) {
    return $_GET[$key];    
  }
  else {
    return $default;
  }
}

/**
 * Enter description here...
 *
 * @param unknown_type $form
 */
function theme_icl_content_dashboard_nodes($form) {
  drupal_add_css(drupal_get_path('module', 'icl_content').'/css/dashboard.css');
  
  $has_posts = count(element_children($form['title'])) > 0;
  $select_header = $has_posts ? theme('table_select_header_cell') : '';
  $header = array($select_header, t('Title'), t('Type'), t('Status'), t('Translation'));
  
  if ($has_posts) {
    foreach (element_children($form['title']) as $key) {
      $row = array();      
      $row[] = drupal_render($form['nodes'][$key]);
      $row[] = drupal_render($form['title'][$key]);
      $row[] = drupal_render($form['type'][$key]);
      $row[] = drupal_render($form['status'][$key]);
      $row[] = drupal_render($form['translation'][$key]);      
      $rows[] = $row;
    }
    
  }
  else {
    $rows[] = array(array('data' => t('No content available.'), 'colspan' => '6'));
  }
  
  $output = theme('table', $header, $rows);
  
  return $output;
}

function _icl_content_get_review_languages() {
  $languages = array();
  $languages[] = t ('All');

  $langs = _icl_core_available_targets();
  
  foreach($langs as $code => $lang) {
    $languages[$code] = icl_core_get_drupal_language_name_from_ican_language($lang->name);
  }
  return $languages;
}

function icl_content_translation_review() {
  $form = array();
  $form['message'] = array(
    '#type' => 'fieldset',
    '#title' => t('Completed Translations'),
    '#value' => "<br>" . t('The following translations have been received and are waiting for review'),
  );

  $languages = _icl_content_get_review_languages();
  
  $default = _icl_content_review_default_value('review_language', array_shift(array_keys($languages)));
  if ($default == 'All') {
    // handle language neutral setting
    $default = '0';
  }
  $form['message']['review_language'] = array(
    '#title' => t('Show documents in'),
    '#type' => 'radios',    
    '#options' => $languages,
    '#default_value' => $default,
  );
  $form['message']['op'] = array(
    '#value' => t('Update display'),
    '#type' => 'submit',
    '#submit' => array('icl_content_review_filter_form_submit'),
  );

  $form['nodes'] = icl_content_dashboard_nodes_form(FALSE);
  $form['pager'] = array('#value' => theme('pager', NULL, 10, 0));
    
  return $form;
}

/**
 * Enter description here...
 *
 */
function icl_content_review_filter_form_submit($form, &$form_state) {
  global $icl_content_review_filter;
  
  $icl_content_review_filter = array(
    'review_language' => $form_state['values']['review_language'],
  );
  if ($icl_content_review_filter['review_language'] == '0') {
    // handle all language setting
    $icl_content_dashboard_filter['review_language'] = '';
  }
  $form_state['rebuild'] = TRUE;
}

function _icl_content_review_default_value($key, $default) {
  global $icl_content_review_filter;
  
  if (isset($icl_content_review_filter[$key])) {
    return $icl_content_review_filter[$key];
  }
  else if (isset($_GET[$key])) {
    return $_GET[$key];    
  }
  else {
    return $default;
  }
}

function icl_content_review_build_filter_query() {

  $lang = _icl_content_review_default_value('review_language', array_shift( array_keys(_icl_content_get_review_languages()) ));
  
  $node_types = _icl_content_translatable_node_types();
  
  $filter = array();  
  
  $filter['join'] .= ' INNER JOIN {icl_content_status} cs ON n.tnid = cs.nid 
                       INNER JOIN {icl_core_status} c ON c.rid = cs.rid';
  $filter['where'] .= " AND c.status = " . ICL_STATUS_SUCCESSFUL;
  
  if ($lang != "0") {
    $filter['where'] .= " AND n.language = '" . $lang . "'";
  }
  $sql  = "SELECT 
             distinct n.nid, 
             n.title, 
             n.type, 
             n.language, 
             n.status,
             n.tnid
           FROM 
             {node} n"
           .$filter['join'].
          " WHERE
             n.type IN ('".implode("', '", $node_types)."') AND 
             n.tnid != n.nid AND
             n.status = 0"
           .$filter['where'];
  
  $count_query = preg_replace(array('/SELECT.*?FROM /As', '/ORDER BY .*/'), array('SELECT COUNT(distinct n.nid) FROM ', ''), $sql);
  
  return pager_query($sql, 10, 0, $count_query);
}
