<?php
/* 
 * $Id: icl_core.settings.inc,v 1.37 2009/04/07 05:24:57 brucepearson Exp $
 * 
 * @file Page handler for admin settings callback
 */

module_load_include ( 'inc', 'icl_core', 'icl_core.webservices' );
module_load_include ( 'inc', 'icl_core', 'icl_core.constants' );

/**
 * check to see if the required i18n mdules are installed
 *
 * @return a list of modules not installed.
 */

function check_i18n_installed() {
  $not_installed = array();
  
  if (!module_exists ( 'i18ntaxonomy' )) {
    $not_installed[] = array(
                             "module" => 'i18ntaxonomy',
                             "message" => t ('Please enable the i18n taxonomy module so taxonomy can be translated.'),
                            );
  }
  if (!module_exists ( 'i18nblocks' )) {
    $not_installed[] = array(
                             "module" => 'i18nblocks',
                             "message" => t ('Please enable the i18n blocks module so user defined blocks can be translated.'),
                            );
  }

  return $not_installed;
}

/**
 * temp class for storing target languages
 */

class lang_targets {
  public $targets = array();
}

function icl_core_elements() {
  $type = array();
  $type['checkbox_columns'] = array('#input' => TRUE, '#process' => array('icl_core_expand_checkbox_columns'), '#tree' => TRUE);
  return $type;
}

function icl_core_expand_checkbox_columns($element) {
  $value = is_array($element['#value']) ? $element['#value'] : array();
  $element['#type'] = 'checkboxes';
  $element['#tree'] = TRUE;
  if (count($element['#options']) > 0) {
    if (!isset($element['#default_value']) || $element['#default_value'] == 0) {
      $element['#default_value'] = array();
    }
    foreach ($element['#options'] as $key => $choice) {
      $class = ($column % $element['#columns']) && $column ? 'checkbox-columns' : 'checkbox-columns-clear';
      if (!isset($element[$key])) {
        $element[$key] = array('#type' => 'checkbox', '#processed' => TRUE, '#title' => $choice, '#default_value' => in_array($key, $value), '#attributes' => $element['#attributes'], '#prefix' => '<div class="' . $class . '">', '#suffix' => '</div>');
      }
      $column++;
    }
  }
  return $element;
}


/**
 * This is a page callback for the ICanLocalize Core admin page
 *
 * @return array The system settings form.
 */
function icl_core_admin_settings() {
  
  drupal_add_js(drupal_get_path('module', 'icl_core') . '/js/icl_core.js');
  drupal_add_css(drupal_get_path('module', 'icl_core').'/css/icl_core.css');
  
  $form = array ();
  $form ['icl_core_setup_instructions'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Getting started' ),
      '#value' => t ( '<div class="status"><b>Need help setting up ICanLocalize Translator? Visit the ') . '<a href="'. ICL_INSTALL_AND_SETUP_GUIDE . '">'. t ( 'getting started guide') . '</a></b></div>'
      );
  
  $i18n_not_installed = check_i18n_installed();
  if (sizeof($i18n_not_installed) > 0) {
    $form['i18n_errors'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Missing i18n modules.' ), 
      '#collapsible' => false );
  
    foreach($i18n_not_installed as $id => $module) {
      $form ['i18n_errors'] [$module['module']] = array (
          '#type' => 'markup', 
          '#prefix' => '<div class="error">', 
          '#suffix' => '</div>', 
          '#value' => $module['message'] );
    }
  }

  // get the installed languages.
  
  $default_language = language_default();
  $languages = language_list('enabled');
  $languages = $languages[1];
  
  // only include languages support in icanlocalize.
  $all_langs = _icl_core_get_all_languages();
  $supported_langs = array();
  
  foreach($languages as $code => $lang) {
    if (isset($all_langs[$lang->name])) {
      if ((int)$all_langs[$lang->name]['id'] != 0) {
        $supported_langs[$code] = $lang;
      }
    }
  }
  
  $languages = $supported_langs;

  
  $ican_languages = NULL;
  $platform_info = array();

  // do we have a website id or accesskey
  
  if (variable_get ( 'icl_core_website_id', '' ) != '' || variable_get ( 'icl_core_accesskey', '' ) != '') {
    // check we can access with this info.
    $ican_languages = icl_core_available_languages ( TRUE, $platform_info );
  } else {
    // set up the default to translate from the default language to all other languages.
    
    $ican_languages = array(
      $default_language->language => new lang_targets(),
    );
    foreach ($languages as $code => $lang) {
      if ($code != $default_language->language) {
        $ican_languages[$default_language->language]->targets[$code] = 1;
      }
    }
  }
  
  
  $form ['language_settings'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Languages' ), 
      '#collapsible' => FALSE);
  
  if (sizeof($languages) == 1) {  
    $form ['language_settings'] ['no_languages'] = array (
        '#type' => 'markup', 
        '#prefix' => '<div class="error"><b>', 
        '#suffix' => '</b></div>', 
        '#value' => t ('You only have one language setup or enabled on your Drupal site. Please add or enable additional languages - <a href="!add_languages">Add languages.</a>', array('!add_languages' => url('admin/settings/language/add'))) );
  } else {
    
    $form ['language_settings'] ['more_languages'] = array (
        '#type' => 'markup', 
        '#prefix' => '<div class="status"><b>', 
        '#suffix' => '</b></div>', 
        '#value' => t ('You can include additional languages - <a href="!add_languages">Add languages.</a>', array('!add_languages' => url('admin/settings/language/add'))) );

    foreach ($languages as $code => $lang) {
      $form ['language_settings'] ['source_languages_' . $code] = array (
        '#type' => 'checkbox',
        '#title' => t("Translate from !language", array('!language' => $lang->name)),
        '#default_value' => isset($ican_languages[$code]),
        '#description' => t("Allows content to be translated from !language to other languages.", array('!language' => $lang->name)),
        '#attributes' => array('onclick' => "javascript:on_lang_from($(this), '" . $code . "');"),
        );
      $dest_languages = array();
      
      $dest_languages_enabled = array();
      
      foreach ($languages as $dest_code => $dest_lang) {
        if ($dest_code != $code) {
          $dest_languages[$dest_code] = $dest_lang->name;
          if (isset($ican_languages[$code]->targets[$dest_code])) {
            $dest_languages_enabled[] = $dest_code;
            if (!$ican_languages[$code]->targets[$dest_code]->have_translators) {
              $dest_languages[$dest_code] .= t(' (No translators have been assigned yet)');
            }
          }
          $dest_languages['own_'.$dest_code] = t('Assign !lang to my translator', array('!lang' => $dest_lang->name));
          if (isset($ican_languages[$code]->targets[$dest_code]->pay_per_use)) {
            if ($ican_languages[$code]->targets[$dest_code]->pay_per_use) {
              $dest_languages_enabled[] = 'own_'.$dest_code;
            }
          }
        }
      }
      
      $attributes = array('id' => 'dest_languages_' . $code);
      if (!isset($ican_languages[$code])){
        // hide the to languages
        $attributes['style'] = "display: none;";
      }
      
      
      $form ['language_settings'] ['field_dest_languages_' . $code] = array(
          '#type' => 'fieldset', 
          '#title' => t ( 'Translate to these languages' ), 
          '#collapsible' => false,
          '#attributes' => $attributes,
          );
      
      $form ['language_settings'] ['field_dest_languages_' . $code] ['dest_languages_' . $code] = array (
        '#type' => 'checkbox_columns',
        '#title' => "",
        '#columns' => 2,
        '#options' => $dest_languages,
        '#default_value' => $dest_languages_enabled,
        '#description' => '<br style="clear:both"/>' . t("Allows content to be translated from !language to these languages. Languages that don't have a translator available for doing translations are marked as (No translators have been assigned yet)", array('!language' => $lang->name)),
        '#attributes' => array('onclick' => "javascript:on_translator_select();"),
        '#suffix' => '<br style="clear:both"/>',
      );
      
    }
  }

  $form ['icl_core_translator_selection'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Translator selection' ), 
      '#collapsible' => FALSE);

  $options = array (
      ICL_CORE_SELECT_TRANSLATORS_ICANLOCALIZE => t ( 'Let ICanLocalize choose the best translator for me.' ), 
      ICL_CORE_SELECT_TRANSLATORS_CLIENT => t ( 'I want to choose translators.' ),
      ICL_CORE_SELECT_TRANSLATORS_PRIVATE => t ( 'Use my own translators.' ),
      );
  $form ['icl_core_translator_selection'] ['icl_core_translator_selection'] = array (
      '#type' => 'radios', 
      '#title' => t ( 'Select how you want to select translators' ), 
      '#multiple' => FALSE, 
      '#options' => $options, 
      '#default_value' => variable_get ( 'icl_core_translator_selection', ICL_CORE_SELECT_TRANSLATORS_ICANLOCALIZE ), 
      '#description' => t ( 'If you want to choose translators, you will be notified by email whenever a translator applies to work on your project.' ),
      '#attributes' => array('onclick' => "javascript:on_translator_select();"),
      );
  $form['icl_core_translator_selection'] ['private_transaltors'] = array(
            '#type' => 'markup', 
          '#prefix' => '<div id="icl_core_private_translator_message">', 
          '#suffix' => '</div>', 
          '#value' => t('To invite your own translators to work on this project, visit your !private_translators page (requires logging in to ICanLocalize)', array('!private_translators' => ICL_PRIVATE_TRANSLATORS)));

  if ($platform_info['free_usage']) {
    $form['icl_core_translator_selection'] ['free_usage'] = array(
            '#type' => 'markup',
            '#prefix' => '<div class="status"><b>', 
            '#suffix' => '</b></div>', 
            '#value' => t('Usage fees for ICanLocalize Translator have been waived for this project.'));
  }

  $options = array (
      ICL_CORE_RECEIVE_XMLRPC => t ( 'Translations will be posted back to this Drupal website via XML-RPC' ), 
      ICL_CORE_RECEIVE_POLL => t ( 'This Drupal installation will poll for translations' ) );
  $form ['icl_core_delivery'] = array (
      '#type' => 'fieldset', 
      '#title' => t ( 'Translation delivery' ), 
      '#collapsible' => FALSE);
  $form ['icl_core_delivery'] ['icl_core_receive_options'] = array (
      '#type' => 'radios', 
      '#title' => t ( 'Select the desired translation delivery method' ), 
      '#multiple' => FALSE, 
      '#options' => $options, 
      '#default_value' => variable_get ( 'icl_core_receive_options', ICL_CORE_RECEIVE_XMLRPC ), 
      '#description' => t ( 'Choose polling if your site is inaccessible from the Internet' ) );
  $form ['icl_core_delivery'] ['icl_core_notifications'] = array (
      '#type' => 'checkboxes', 
      '#title' => t ( 'Notification preferences' ), 
      '#options' => array('1' => 'Send an email notification when translations complete',
                          '2' => 'Send an alert when translations delay for more than 4 days'),
      '#default_value' => variable_get('icl_core_notifications', array('1', '2')),
      '#description' => t("ICanLocalize will send notifications messages via email of these events"),
      );

  $disable_save = FALSE;
  
  if (variable_get ( 'icl_core_website_id', '' ) != '' && variable_get ( 'icl_core_accesskey', '' ) != '') {

    $user_status = variable_get('icl_core_user_status', -1);
    if ($user_status == ICL_USER_STATUS_NEW) {
      $user_id = variable_get('icl_core_user_id', -1);
      if ($user_id != -1) {
        $form ['icl_core_user'] = array (
            '#type' => 'fieldset', 
            '#title' => t ( 'Email verification required' ), 
            '#collapsible' => FALSE);
        $text = t ('You need to validate your email address by clicking on the validation link in the confirmation email we’ve sent you. If you need we can !link.', array('!link' => ICL_EMAIL_VERIFY_LINK));
        $text = str_ireplace("!USER_ID", (string)$user_id, $text);
        $form ['icl_core_user'] ['icl_core_user_message'] = array(
          '#type' => 'markup',
          '#value' => $text,
        );
      }
      
    } elseif ($user_status == ICL_USER_STATUS_CLOSED) {
      $form ['icl_core_user'] = array (
          '#type' => 'fieldset', 
          '#title' => t ( 'ICanLocalize account closed' ), 
          '#collapsible' => FALSE);
      $form ['icl_core_user'] ['icl_core_user_message'] = array(
        '#type' => 'markup',
        '#value' => 'Your ICanLocalize account has been closed. Translation is disabled.',
      );
      
      $disable_save = TRUE;
      
    } elseif ($user_status == ICL_USER_STATUS_REGISTERED) {
      
      $form ['icl_core_balance'] = array (
          '#type' => 'fieldset', 
          '#title' => t ( 'ICanLocalize account balance' ), 
          '#collapsible' => FALSE);
      $form ['icl_core_balance']['icl_core_balance_message'] = array (
          '#type' => 'markup',
          '#value' => t ("There's no up-front or subscription payment for using ICanLocalize Translator. You pay only for translation jobs that you send. You can make your first payment when sending documents to translation. !more_info", array('!more_info' => ICL_DRUPAL_TRANSLATION_INFO)),
          );
      $form ['icl_core_balance'] ['icl_balance_warning'] = array (
          '#type' => 'textfield', 
          '#title' => t ( 'Account balance warning' ), 
          '#default_value' => number_format((float)variable_get ( 'icl_balance_warning', 50 ), 2, '.', ''), 
          '#description' => t ( 'Warn me when the account balance goes below this value, in USD'));
    } else {
      // undefined user status.
      $form ['icl_core_user'] = array (
          '#type' => 'fieldset', 
          '#title' => t ( 'Account not properly setup' ), 
          '#collapsible' => FALSE);
      $text = t ('It appears that your account at ICanLocalize is not properly set up. Please !link to have this fixed.', array('!link' => ICL_SUPPORT_LINK));
      $form ['icl_core_user'] ['icl_core_user_message'] = array(
        '#type' => 'markup',
        '#value' => $text,
      );
      
      
      
    }
  

    $form ['access_settings'] = array (
        '#type' => 'fieldset', 
        '#title' => t ( 'Access settings' ), 
        '#collapsible' => true,
        '#collapsed' => true);
    $form ['access_settings'] ['icl_core_website_id'] = array (
        '#type' => 'textfield', 
        '#title' => t ( 'Website ID' ), 
        '#default_value' => variable_get ( 'icl_core_website_id', '' ), 
        '#description' => t ( 'The website ID you received from ') . ICL_ICANLOCALIZE_LINK );
    $form ['access_settings'] ['icl_core_accesskey'] = array (
        '#type' => 'textfield', 
        '#title' => t ( 'Accesskey' ), 
        '#default_value' => variable_get ( 'icl_core_accesskey', '' ), 
        '#description' => t ( 'The accesskey you received from ') . ICL_ICANLOCALIZE_LINK );

    if (is_string ( $ican_languages )) {
      // we have an error.
      $form ['access_settings']['#collapsed'] = FALSE;
      
      $form ['access_settings'] ['access_error'] = array (
          '#type' => 'markup', 
          '#prefix' => '<div class="error">', 
          '#suffix' => '</div>', 
          '#value' => $ican_languages );
    } else {
      // website id and accesskey are ok.
      
      $form ['access_settings'] ['access_ok'] = array (
          '#type' => 'markup', 
          '#prefix' => '<div class="status">', 
          '#suffix' => '</div>', 
          '#value' => t("Webite ID and Accesskey verified."));
      $form ['access_settings'] ['site_info'] = array (
          '#type' => 'markup', 
          '#prefix' => '<div id="language-wrapper">', 
          '#suffix' => '</div>', 
          '#value' => t("ICanLocalize project name: <b>") . $platform_info['name'] . "</b><br />" . t("ICanLocalize project description: <b>") . $platform_info['description'] . "</b><br />");
    }
  } else {
    $form ['project_setup'] = array (
        '#type' => 'fieldset', 
        '#title' => t ( '<b>Project settings</b>' ), 
        '#collapsible' => false );
    
    $form ['project_setup'] ['icl_core_project_name'] = array (
        '#type' => 'textfield', 
        '#title' => t ( 'Project name' ), 
        '#default_value' => variable_get('icl_core_project_name', variable_get('site_name', '')),
        '#description' => t ( 'Used to identify the project. Use a clear descriptive name.') );
    $form ['project_setup'] ['icl_core_project_description'] = array (
        '#type' => 'textarea', 
        '#title' => t ( 'Project description' ), 
        '#default_value' => variable_get('icl_core_project_description', variable_get('site_slogan', '')), 
        '#description' => t ( 'Provide a short description of the website so that translators know what background is required from them.') );
    
    // we don't have a website id or accesskey so assume a new setup.
    $form ['icanlocalize_setup'] = array (
        '#type' => 'fieldset', 
        '#title' => t ( '<b>ICanLocalize Account</b>' ), 
        '#collapsible' => false );
    $form ['icanlocalize_setup'] ['message'] = array (
          '#type' => 'markup',
          '#prefix' => '<div id="icl_core_account_message">',
          '#suffix' => '</div>',
          '#value' => t("An account will be created for you in ICanLocalize, in order to do translations."));
    $form ['icanlocalize_setup'] ['icl_core_first_name'] = array (
        '#type' => 'textfield', 
        '#title' => t ( 'First name' ), 
        '#default_value' => variable_get('icl_core_first_name', ''), 
        '#description' => t ( 'Used for the ICanLocalize account. Will not be shared with other users'),
        );
    $form ['icanlocalize_setup'] ['icl_core_last_name'] = array (
        '#type' => 'textfield', 
        '#title' => t ( 'Last name' ), 
        '#default_value' => variable_get('icl_core_last_name', ''), 
        '#description' => t ( 'Used for the ICanLocalize account. Will not be shared with other users.'),
        );
    $form ['icanlocalize_setup'] ['icl_core_email_address'] = array (
        '#type' => 'textfield', 
        '#title' => t ( 'Email address' ), 
        '#default_value' => variable_get('icl_core_email_address', ''), 
        '#description' => t ( 'The administrative contact for your account. Not shared with other users.'),
        '#required' => TRUE);
    $form ['icanlocalize_setup'] ['icl_core_password'] = array (
        '#type' => 'password', 
        '#title' => t ( 'Password' ), 
        '#default_value' => variable_get('icl_core_password', ''), 
        '#description' => t ( "Enter your ICanlocalize password. If you don't have a password, select 'I need to create an account at ICanLocalize' below."),
        );
    $form ['icanlocalize_setup'] ['icl_core_button'] = array (
        '#type' => 'button', 
        '#value' => t ( 'I already have an account at ICanLocalize' ),
        '#attributes' => array('onclick' => "javascript:on_account_button();return false;"),
        );
    $form ['icanlocalize_setup'] ['icl_core_do_create'] = array (
        '#type' => 'hidden',
        '#value' => TRUE,
        );
    
  }
  
  
  $form = system_settings_form ( $form );
  
  unset($form['buttons']['reset']);
  
  if ($disable_save) {
    $form['buttons']['submit']['#attributes'] = array('disabled' => 'disabled');
  }
  return $form;
}

/**
 * Validate the form and make sure we have a website id and accesskey
 *
 */

function icl_core_admin_settings_validate($form, &$form_state) {
  
  global $base_url;

  $languages = array();
  
  foreach ($form_state['values'] as $key => $value) {
    if (strpos($key, 'dest_languages_') === 0) {
      $source_lang = substr($key, strlen('dest_languages_'));
      $languages[$source_lang] = array();
      
      if ($form_state['values']['source_languages_' . $source_lang]) {
        foreach ($form_state['values'][$key] as $key_dest => $value_dest) {
          if ($value_dest) {
            $languages[$source_lang][] = $key_dest;              
            
          }
        }        
      }
    }
  }
  
  $notifications = 0;
  foreach($form_state['values']['icl_core_notifications'] as $key => $value) {
    if ($key == $value) {
      $notifications += pow(2, (int)$key - 1);
    }
  }
  
  if (isset($form['access_settings'])) {
      
    if($form_state['values']['icl_core_website_id'] == '') {
      form_set_error('', t('Please enter a website ID that you received from ') . ICL_ICANLOCALIZE_LINK );
    }
    elseif($form_state['values']['icl_core_accesskey'] == '') {
      form_set_error('', t('Please enter an accesskey that you received from ') . ICL_ICANLOCALIZE_LINK );
    }
    
    // we have a website id and access key.

    // set update settings to icanlocalize
    
    $result = icl_core_update_cms($form_state['values']['icl_core_accesskey'],
                                      $form_state['values']['icl_core_website_id'],
                                      $form_state['values']['icl_core_translator_selection'] == ICL_CORE_SELECT_TRANSLATORS_ICANLOCALIZE ? 0 : 1,
                                      $base_url,
                                      variable_get('icl_core_project_name', ''),
                                      variable_get('icl_core_project_description', ''),
                                      $form_state['values']['icl_core_receive_options'] == ICL_CORE_RECEIVE_POLL,
                                      $languages,
                                      $notifications);
    if (is_string ( $result )) {
      // we got an error
      form_set_error('', $result);
    }
    
    
    
  } else {
    if(!valid_email_address($form_state['values']['icl_core_email_address'])) {
      form_set_error('', t('Please enter a valid email address'));
    } else {
      
      // Accound setup mode.
      
      $create_account = $_POST['icl_core_do_create'] == '1';
      
      $first = $form_state['values']['icl_core_first_name'];
      $last = $form_state['values']['icl_core_last_name'];
      $pass = $form_state['values']['icl_core_password'];
      
      if ($create_account) {
        if($first == '') {
          form_set_error('', t('Please enter your first name') );
          return;
        }
        if($last == '') {
          form_set_error('', t('Please enter your last name') );
          return;
        }

        $pass = "";
      } else {
        if($pass == '') {
          form_set_error('', t('Please enter your password for access to ICanLocalize') );
          return;
        }
        
        $first = "";
        $last = "";
      }

      // everything is ok so we can submit to icanlocalize
      $result = icl_core_create_account($form_state['values']['icl_core_email_address'],
                                        $create_account,
                                        $first,
                                        $last,
                                        $pass,
                                        $form_state['values']['icl_core_translator_selection'] == ICL_CORE_SELECT_TRANSLATORS_ICANLOCALIZE ? 0 : 1,
                                        $base_url,
                                        $form_state['values']['icl_core_project_name'],
                                        $form_state['values']['icl_core_project_description'],
                                        $form_state['values']['icl_core_receive_options'] == ICL_CORE_RECEIVE_POLL,
                                        $languages,
                                        $notifications);
      if (is_string ( $result )) {
        // we got an error
        form_set_error('', $result);
      }
    
    // All is ok so inform the user.
    
    $message_data = array('!email_address' => $form_state['values']['icl_core_email_address'],
                          '!password_reminder' => ICL_PASSWORD_REMINDER);
    drupal_set_message(t ("An account was created for you in ICanLocalize for translating this website. A verification email was sent to !email_address. Please check your mailbox and respond to that email. If you didn't receive the confirmation email, go to !password_reminder and request to have it resent to you.", $message_data));
    }
    
  }
}

/**
 * AHAH callback for ICanLocalize admin page
 * Returns the enabled languages for translation or an error message
 * when no languages are enabled.
 *
 */
function icl_core_retrieve_langs_js() {
  print drupal_to_js ( array (
      'status' => TRUE, 
      'data' => _icl_core_settings_language_list ( TRUE ) ) );
  exit ();
}

/*
 * Creates the available language list
 * 
 * @param $cache_clear TRUE to empty the internal caches, FALSE otherwise
 */
function _icl_core_settings_language_list($clear_cache = FALSE) {
  
  if ($clear_cache) {
    // we need record the current website id and accesskey and then
    // use the ones the user has entered on the settings page to get
    // the langauges setup on icanlocalize.
    
    $original_wid = variable_get ( 'icl_core_website_id', FALSE );    
    $original_accesskey = variable_get ( 'icl_core_accesskey', FALSE );
    
    // get the form state
    
    $form_state = array('storage' => NULL, 'submitted' => FALSE);
  
    $form = form_get_cache($_POST['form_build_id'], $form_state);
    $form['#post'] = $_POST;
  
    drupal_process_form('icl_core_admin_settings', $form, $form_state);
    
    // Use the website and accesskey the user has entered.
    
    variable_set('icl_core_website_id', $form_state['values']['icl_core_website_id']);
    variable_set('icl_core_accesskey', $form_state['values']['icl_core_accesskey']);
  }
  
  if($form_state['values']['icl_core_website_id'] != variable_get ( 'icl_core_website_id', '' ) || 
    $form_state['values']['icl_core_website_id'] != variable_get ( 'icl_core_website_id', '' ))
  {
        $clear_cache = TRUE;
        variable_set ( 'icl_core_languages', array() );
        $original_wid = variable_get ( 'icl_core_website_id', FALSE );    
        $original_accesskey = variable_get ( 'icl_core_accesskey', FALSE );
  }
  
  $platform_info = array();
  $languages = icl_core_available_languages ( $clear_cache, $platform_info );

  if ($clear_cache) {
    variable_set('icl_core_website_id', $original_wid);
    variable_set('icl_core_accesskey', $original_accesskey);
  }
  
  if (is_string ( $languages )) {
    if ($languages == '-1 cannot access') {
      $languages = t ('Cannot retrieve the languages from the ICanLocalize server. Please check the website ID and access key.');
    }
    return '<div class="error">' . $languages . '</div>';
  }
  
  if (empty ( $languages )) {
    $output = '<div class="error">' . t ( 'No languages have been defined. Please define at least one in your setup on ' ) . ICL_ICANLOCALIZE_LINK . '<br>' . t ('See ') . '<a href="' . ICL_INSTALL_AND_SETUP_GUIDE_LANGUAGES . '">' . t ('Install and setup guide') . '</a>' . t(' for details.') . '</div>';
  } else {
    $pairs = array ();
    if ($platform_info['platform'] != ICL_DRUPAL_PROJECT_KIND) {
      // not a drupal platform
      $output = '<div class="error">' . t ( 'The project is not setup as a Drupal project on ICanLocalize. Please goto !ICanLocalize and correct the project kink.', array("!ICanLocalize" => ICL_ICANLOCALIZE_LINK)) . "</div>";
    } else {
      
      $output = "";
      
      $output .= t("ICanLocalize project name: <b>") . $platform_info['name'] . "</b><br />";
      $output .= t("ICanLocalize project description: <b>") . $platform_info['description'] . "</b><br />";
      
      $pickup = variable_get ( 'icl_core_receive_options', ICL_CORE_RECEIVE_XMLRPC ) == ICL_CORE_RECEIVE_POLL;
      if (isset($form_state['values']['icl_core_receive_options'])) {
        $pickup = $form_state['values']['icl_core_receive_options'] == ICL_CORE_RECEIVE_POLL;
      }
      
      if($platform_info['pickup'] != $pickup) {
        $output .= '<div class="error">' . t ( 'The translation delivery method is different on ICanLocalize. Please select the same delivery method as set on !ICanLocalize.', array("!ICanLocalize" => ICL_ICANLOCALIZE_LINK)) . "</div>";
      }

      
      foreach ( $languages as $from ) {
        foreach ( $from->targets as $to ) {
          $temp = t ( 'From %from to %to', array (
              '%from' => $from->name, 
              '%to' => $to->name ) );
          if (! $from->enabled || ! $to->enabled) {
            $temp .=  '<div class="error">'. t ('Disabled or not selected in Drupal.') . '</div>' . t ('Add appropriate languages on !locale settings page or enable them if they are already added.', array (
                '!locale' => l ( t ( 'Language' ), 'admin/settings/language/add', array (
                    'query' => 'destination=admin/settings/icl-core' ) ) ) ) ;
          }
          $pairs [] = $temp;
        }
      }
      $output .= '<ul><li>' . implode ( '</li><li>', $pairs ) . '</li></ul>';
    }
  }
  
  return $output;
}